% Mbdist_vs_mass.m script
% Script for showing the Maxwell-Boltzmann distribution for different masses
% Jason Kahn U Maryland 2/25/2016  version 1.01
% Edit the three vectors below to control illustration. 
% Clumsy; should rewrite for arbitrary number of masses, and pre-compute
% maximum velocities and kinetic energies for optimal scaling
% Calls the createMBfig function to give the distributions.
% Makes two plots, one vs v and one vs K.E.
%
massvec = [8,20,50,100];
Tvec = [300, 300, 300, 300];
maxv = [2100, 1400, 850, 600];
% 
% Should be automatic from here down.
%
numm = length(massvec);
% Values used for optimization of the display
% massvec = [8,20,50,100];
% Tvec = [300, 300, 300, 300];
% maxv = [2300, 1500, 1000, 800];
%
[v1,pv1,vd1,pd1,fig] = createMBfig(massvec(1),Tvec(1),maxv(1),1); 
close(fig)
[v2,pv2,vd2,pd2,fig] = createMBfig(massvec(2),Tvec(2),maxv(2),1);  
close(fig)
[v3,pv3,vd3,pd3,fig] = createMBfig(massvec(3),Tvec(3),maxv(3),1);  
close(fig)
[v4,pv4,vd4,pd4,fig] = createMBfig(massvec(4),Tvec(4),maxv(4),1);  
close(fig)
legmat = cell(size(massvec,2),1);

% Create figure
scrsz = get(0,'ScreenSize');

figure1 = figure('Position',[100 scrsz(4)/2 scrsz(3)/2 scrsz(4)/2]);

% Create axes
axes1 = axes('Parent',figure1,'ZColor',[0 0.5 0],...
    'YColor',[0 0.5 0],...
    'XColor',[0 0.5 0],...
    'FontWeight','bold',...
    'FontSize',14);
box(axes1,'on');
hold(axes1,'all');

% Create multiple lines using matrix input to plot
for i = 1:numm
    legmat(i) = {[' M = ', num2str(massvec(i))]};
end
plot(v1,pv1,'LineWidth',2,'Parent',axes1);
plot(v2,pv2,'LineWidth',2,'Parent',axes1);
plot(v3,pv3,'LineWidth',2,'Parent',axes1);
plot(v4,pv4,'LineWidth',2,'Parent',axes1);


% Create xlabel
xlabel('Velocity v (m/s)','FontWeight','bold','FontSize',14,...
    'Color',[0 0.5 0]);

% Create ylabel
ylabel('Normalized Probability P(v)','FontWeight','bold','FontSize',14,...
    'Color',[0 0.5 0]);

% Create annotations and legend
%text(0.4*maxv,0.98*max(max(probv)),['Particle mass = ',num2str(molwt)],...
 %   'FontWeight','bold','FontSize',14)
legend(legmat)

% Create title
title('Maxwell-Boltzmann Distribution of Particle Speed',...
    'FontWeight','bold',...
    'FontSize',16);

% Create second figure
scrsz = get(0,'ScreenSize');

figure2 = figure('Position',[100 scrsz(4)/2 scrsz(3)/2 scrsz(4)/2]);

% Create axes
axes2 = axes('Parent',figure2,'ZColor',[0 0.5 0],...
    'YColor',[0 0.5 0],...
    'XColor',[0 0.5 0],...
    'FontWeight','bold',...
    'FontSize',14);
box(axes2,'on');
hold(axes2,'all');

% Create multiple lines using matrix input to plot
%for i = 1:numm
%    legmat(i) = {[' M = ', num2str(massvec(i))]};
%end
% To normalize properly to energy, plot e.g.
%plot(.5*massvec(2)*v2.^2,pv2./sqrt(massvec(2)),'LineWidth',2,'Parent',axes2);
% But then all the plots collapse to one line at constant T
plot(.5*massvec(1)*v1.^2,pv1,'LineWidth',2,'Parent',axes2);
plot(.5*massvec(2)*v2.^2,pv2,'LineWidth',2,'Parent',axes2);
plot(.5*massvec(3)*v3.^2,pv3,'LineWidth',2,'Parent',axes2);
plot(.5*massvec(4)*v4.^2,pv4,'LineWidth',2,'Parent',axes2);
plot(.5*massvec(1)*vd1.^2,pd1,'ko')
plot(.5*massvec(2)*vd2.^2,pd2,'ko')
plot(.5*massvec(3)*vd3.^2,pd3,'ko')
plot(.5*massvec(4)*vd4.^2,pd4,'ko')
for k = 1:3
    plot([.5*massvec(4)*vd4(k).^2 .5*massvec(4)*vd4(k).^2],[0 pd4(k)],'r-')
end


% Create xlabel
xlabel('Kinetic energy = 1/2*mass*Velocity squared','FontWeight','bold','FontSize',14,...
    'Color',[0 0.5 0]);

% Create ylabel
ylabel('Incompletely Normalized Probability P(v)*sqrt(m)','FontWeight','bold','FontSize',14,...
    'Color',[0 0.5 0]);

% Create annotations and legend
%text(0.4*maxv,0.98*max(max(probv)),['Particle mass = ',num2str(molwt)],...
 %   'FontWeight','bold','FontSize',14)
legend(legmat)

% Create title
title('Maxwell-Boltzmann Distribution of Particle Energy',...
    'FontWeight','bold',...
    'FontSize',16);
str = {'Distributions are not normalized by (1/sqrt(m))...','','If they were they would all be the same line at constant T'};
text(0.5*.5*massvec(1)*maxv(1)^2,0.8*max(pv4),str,'FontSize',14)


